# Von Maschinen fürs Leben lernen

von Stefan Majewsky, Chaos Computer Club Dresden <mailto:xyrill@c3d2.de>

Der Chaos Computer Club (CCC) ist eine Vereinigung, deren Mitglieder sich hauptsächlich durch technische Expertise auszeichnen. Insofern nimmt die Mehrheit der Gesellschaft überlicherweise an, dass wir alle Probleme technisch lösen wollen: Sicherheit im Netz durch mehr Kryptografie, lebenswertere Innenstädte durch intelligentere Ampelschaltungen, oder Virusinfektionen durch eine Contact-Tracing-App. Gerade der CCC zeichnet sich jedoch seit Beginn dadurch aus, dass wir technische und soziale Fragen immer zusammen denken.

Für uns ist es zum Beispiel schon lange offensichtlich, dass man die Frage nach zeitgemäßer Bildung im digitalen Zeitalter nicht allein dadurch beantworten kann, dass die Politik über den Schulen des Landes einen warmen Regen aus Tablets und Notebooks ergehen lässt. Digitale Lerninhalte können sicherlich den Lehralltag bereichern. Aber die entscheidendere Frage ist, inwieweit die Digitalisierung die Grundsätze unseres Bildungssystems in Zweifel zieht. Die fortschreitende Automatisierung macht vielleicht nicht so viele Arbeitsplätze obsolet wie manchmal angenommen, aber an jedem einzelnen Arbeitsplatz werden Routinetätigkeiten zunehmend von Computern übernommen, sodass vom Mitarbeiter verstärkt kreative und analytische Fertigkeiten verlangt werden.

Diesen Wandel muss auch die Bildung begleiten. Anstatt zum Beispiel einen bestimmten Satz von Fakten über ein im Lehrplan vorgegebenes Thema auswendig zu lernen, sollte das Ziel sein, den Schülern die Kompetenz mitzugeben, sich zu jedem beliebigen Thema informieren zu können, dabei technische Hilfsmittel zum Sichten großer Datenmengen zu nutzen, und erfolgreich Fakten von Meinungen und seriöse Berichterstattung von Fake News zu trennen. Ein derartiger Bildungsprozess muss sicherlich mit digitalen Hilfsmitteln arbeiten. Aber er fokussiert sich auf die Dinge, die Menschen wirklich gut machen: kreatives und kritisches Denken. Und er überlässt den Maschinen die Dinge, die sie besser können: Routinetätigkeiten und die Verarbeitung großer Datenmengen.

Und doch, oder vielleicht gerade deshalb, trägt dieser Text die Überschrift "Von Maschinen fürs Leben lernen". Im Folgenden werden beispielhaft drei Lebenslektionen besprochen, die der Autor aus seinem Studium der Informatik sowie aus seiner Tätigkeit in der IT-Branche gezogen hat, und die unserer Meinung nach in den Lehrplänen aktuell zu wenig Beachtung finden. Solange dies so bleibt, könnte auch ein Computermuseum wie das ZCOM entsprechende Impulse setzen.

## Lektion 1: Game of Life

Vielleicht nicht eines der wichtigsten, aber sicherlich eines der bekanntesten Untersuchungsobjekte der Informatik ist "Conway's Game of Life" (GoL). Hierbei handelt es sich um einen zellulären Automaten, also eine Anordnung von Zellen, wobei jede Zelle einen bestimmten Zustand hat und diesen Zustand in festen diskreten Zeitschritten nach bestimmten Regeln wechseln kann. Man kann zelluläre Automaten in beliebig vielen Raumdimensionen und mit allen denkbaren Zellformen konstruieren.

Im konkreten Fall von GoL haben wir ein zweidimensionales Raster aus quadratischen Zellen. Eine Zelle kann zwei mögliche Zustände einnehmen, die für gewöhnlich als "tot" oder "lebendig" bezeichnet werden. Für den Wechsel zwischen diesen beiden Zuständen ist die direkte Nachbarschaft der Zelle relevant, sprich: die Zustände der acht im Quadratraster nächstgelegenen Zellen (oben, unten, links, rechts; plus vier Nachbarn in diagonaler Richtung). Eine tote Zelle wird lebendig, wenn sie exakt drei lebendige Nachbarn hat. Eine lebendige Zelle mit keinem oder nur einem lebendigem Nachbarn stirbt an Vereinsamung, und eine lebendige Zelle mit vier or mehr lebendigen Nachbarn stirbt an Überbevölkerung.

Nun wird der Platz in diesem Aufsatz sicher nicht ausreichen, um eine komplette Diskussion des Verhaltens von GoL zu führen. Und selbst dann hätten wir in einem gedruckten Buch keine gute Möglichkeit, das zeitabhängige Verhalten eines GoL-Spiels abzubilden. Hierfür eignen sich besser Videos oder Live-Simulationen. Sofern der Leser noch nicht mit GoL vertraut ist, ist daher dringend empfohlen, mit einem entsprechenden Simulationsprogramm zu experimentieren. Zum Zeitpunkt der Publikation dieses Textes ist zum Beispiel unter <https://playgameoflife.com> ein derartiges Programm zu finden, welches ohne Installation im Browser läuft und ein umfangreiches Lexikon mit interessanten Startmustern enthält. Der Wikipedia-Artikel zu GoL ist ebenfalls ein guter Startpunkt für eine weitere Auseinandersetzung mit diesem Thema.

GoL wurde im Jahre 1970 von einer Forschergruppe um den britischen Mathematiker John Horton Conway vorgeschlagen. Sie fanden erste interessante Strukturen: Stillleben, die sich nie verändern, und Oszillatoren, die sich verändern, aber nach einer bestimmten Anzahl von Zeitschritten wieder in den Ursprungszustand zurückkehren. Außerdem fanden sie den Gleiter, ein Muster aus 5 lebendigen Zellen, das ähnlich wie ein Oszillator nach vier Zeitschritten wieder in seine ursprüngliche Form zurückkehrt, sich dabei aber diagonal um ein Feld weiterbewegt. Derartige Muster werden im Allgemeinen als Raumschiffe bezeichnet, und nach der initialen Publikation durch die Conway-Gruppe fanden Interessierte schnell weitere Raumschiffe mit unterschiedlichen Bewegungsmustern.

In der initialen Publikation bot Conway ein Preisgeld von 50 US-Dollar für ein Muster, das unbegrenzt wächst. Noch im selben Jahr wurde ein derartiges Muster gefunden: eine sogenannte "Gleiterkanone", die in regelmäßigen Zeitabständen einen Gleiter produziert, der sich dann von der Kanone wegbewegt. Hierdurch kommt ein endloser Strom von Gleitern zustande. Auch für andere Raumschiffe konnten Kanonen konstruiert werden.

Mit der Zeit wurden immer komplexere Strukturen in GoL gebaut. So wie Kanonen Ströme von Raumschiffen erzeugen, können bestimmte Kanonen auch durch Ströme von Raumschiffen an- oder ausgeschaltet werden. Durch strategisches Ausrichten der Raumschiffströme können Kanonen sich gegenseitig kontrollieren und so Logikgatter bilden, aus denen dann ganze Computer gebaut werden können. Im Jahr 2012 gelang die erste Simulation von GoL innerhalb eines GoL-Spielfeldes. [1] Dies demonstriert eindrucksvoll, dass GoL trotz des minimalistischen Regelsatzes turingvollständig ist, sprich: Alle mit einem Computer lösbaren Probleme können theoretisch auch in GoL berechnet werden.

Wenn wir an "Komplexität" denken, denken wir an Systeme mit besonders vielen Regeln, zum Beispiel die Steuergesetzgebung. Viel häufiger jedoch resultiert komplexes Verhalten aus einem System mit einer vergleichsweise kleinen Menge von Regeln, die aber von sehr vielen Akteuren gleichzeitig ausgeführt werden. GoL ist eines der greifbarsten und verständlichsten Beispiele für derartige "emergente Komplexität". Wenn hunderte Zellen an einer Gleiterkanone teilnehmen, hatte die einzelne Zelle keine konkrete Absicht, eine Gleiterkanone zu bilden. Wie eine biologische Zelle kennt sie nur ihre direkte Nachbarschaft und verhält sich dementsprechend, ohne ihren Anteil am Gesamtorganismus zu verstehen.

Emergente Komplexität gibt es nicht nur in der Technik oder der Biologie. Gesellschaft, Wirtschaft und Politik sind selbst Systeme mit vielen Akteuren, die individuell nach relativ überschaubaren Regeln handeln und deshalb zu emergenter Komplexität neigen. Wer das nicht versteht, ist dazu verurteilt, hypothetischen Entitäten wie "dem Markt" oder "der Politik" Intentionen zu unterstellen, die auf dieser Ebene so nicht existieren und daher auch nicht direkt beeinflusst werden können. Wer hingegen emergente Komplexität auf einer intuitiven Ebene nachvollziehen kann, zum Beispiel durch das Studium von GoL, versteht vielleicht besser, welche politischen Maßnahmen tatsächlich effektiv sind, und in welchen Situationen Simulationen wie in der Epidemiologie oder Computational Sociology zum Verständnis emergent komplexer Systeme beitragen.

[1] Bradbury, Philip: Life in Life. <https://www.youtube.com/watch?v=xP5-iIeKXE8> [16.09.2020]

## Lektion 2: Künstliche Intelligenz (KI)

Seit den 1950er Jahren befasst sich die Informatik mit der Frage, inwieweit Denkprozesse und "Intelligenz" im weitesten Sinne in Computern abgebildet werden können. [2] Aufgrund erster vielversprechender Ergebnisse kam es in den 60er und frühen 70er Jahren zu einer ersten Phase der Euphorie. Führende KI-Forscher erwarteten, dass noch vor 1980 Computer die Intelligenz eines durchschnittlichen Menschen erreichen würden. Diese initiale Euphorie verflüchtigte sich in den späten 70er Jahren aus mehreren Gründen, vorrangig aufgrund der Erkenntnis, dass die damalige Rechentechnik noch nicht ausreichend performant war, um die notwendigen Berechnungen in akzeptabler Geschwindigkeit durchzuführen.

Hiermit in Zusammenhang steht ein anderes Problem der frühen KI, das sogenannte Moravec-Paradoxon. Anders als zunächst angenommen, erfordert Intelligenz im engeren Sinne, also logisches Denken, relativ wenig Rechenleistung. Als größere Herausforderung stellen sich sensorische und motorische Fertigkeiten dar. Wenn man zum Beispiel einem Roboterarm das Nähen beibringen möchte, ist der schwierige Teil nicht das Berechnen des richtigen Schnittmusters, sondern das zuverlässige Erkennen der aktuellen Position der Stoffteile sowie das sichere Führen der Nadel.

Eine zweite Phase der Euphorie in den 80er Jahren fokussierte sich daher auf Künstliche Intelligenz im Sinne von logischem Denken. Sogenannte "Expertensysteme" sollten mit dem gesamten Wissen der Menschheit programmiert werden und in Unternehmen oder Forschungseinrichtungen zur Entscheidungsfindung eingesetzt werden. Dieser Boom war jedoch von kurzer Dauer, da sich herausstellte, dass derartige Expertensysteme mit einem enorm hohen Pflegeaufwand verbunden sind. Außerdem sind sie mit einem der Grundprobleme der Ontologie konfrontiert: dem Fehlen einer einheitlichen Klassifikationsstruktur, die alle Themengebiete und Perspektiven des menschlichen Wissens abdecken kann.

Seit den 90er Jahren fokussiert sich die Forschung in der KI daher zunehmend auf das sogenannte "Maschinelle Lernen" (ML), also das Studium und den Einsatz von Computerprogrammen mit begrenzten Aufgabenbereichen, die sich auf der Grundlage passend strukturierter Lerninhalte automatisch selber verbessern können.

Das Forschungsfeld KI ist ein aufgrund seiner Geschwindigkeit besonders drastisches Beispiel, aber die Geschichte der Computertechnik im Allgemeinen ist eine Geschichte gebrochener Erwartungen. Und das gilt auch außerhalb der Computertechnik: Das geozentrische Weltbild, die Äthertheorie und die Rassentheorie sind nur einige Beispiele lange geglaubter Lehrmeinungen, die schließlich revidiert werden mussten. Auch in Politik, Gesellschaft und Ökonomie bestehen populäre Weltbilder regelmäßig nicht den Vergleich mit der Faktenlage.

In einer sich immer schneller weiterentwickelnden Welt ist es daher von elementarer Bedeutung, die eigene Meinung im Angesicht neuer Fakten ändern zu können. Dies klingt auf den ersten Blick trivial, aber Erkenntnisse aus der Psychologie zeigen, dass das Ändern der eigenen Meinung zu den schwersten mentalen Aktivitäten gehört. Gerade deswegen muss diese Fähigkeit immer wieder bewusst geübt werden, damit man im richtigen Moment Kritik oder unpassende Fakten nicht einfach wegdiskutiert, sondern anhalten und reflektieren kann.

Im Bereich der Computertechnik gilt dies sowohl für diejenigen, die ihren Arbeitsplatz für niemals automatisierbar halten, als auch für die Technikgläubigen, die in 2015 vorhergesagt haben, dass wir in 2020 landesweit autonom fahrende Taxis finden werden. Wer seine Vorhersagen nicht kritisch reflektieren kann, ist dazu verdammt, von der Realität überholt zu werden und den Anschluss zu verlieren. Die Frage, wie man diese kritische Reflexion im Kontext des Bildungswesens systematisch trainieren kann, dürfte daher eine der großen Fragen unserer Zeit werden.

[2] Wikipedia: History of artificial intelligence. <https://en.wikipedia.org/w/index.php?title=History_of_artificial_intelligence&oldid=984040105> [18.10.2020]

## Lektion 3: Der Berufsalltag in der IT

In der IT ist es nicht unüblich, auf Mitarbeiter zu treffen, die ihre erste Ausbildung nicht in der Informatik, sondern in einem der naturwissenschaftlichen Fächer absolviert haben. Zum Beispiel hat der Autor seinen ersten IT-Beruf nach Abschluss eines Physikstudiums angetreten und erst in der Folge eine Zusatzqualifikation im Bereich der Informatik erworben. Diese Tendenz hat sicherlich mit den beruflichen Perspektiven zu tun, zum Beispiel mit den Unterschieden in Gehalt und Arbeitsplatzsicherheit zwischen der IT und dem naturwissenschaftlichen Forschungsbetrieb. Aber ein wissenschaftliches Studium lässt sich auch inhaltlich gut auf die Arbeit in der IT übertragen.

Als Wissenschaftler ist man darin geübt, komplexe Systeme auf einfache Modelle herunterzubrechen und diese Modellbildung anhand von Experimenten und Beobachtungen systematisch zu überprüfen. Mit diesem Handwerkzeug ist man gut darauf vorbereitet, die immer komplexer werdenden Computersysteme in Unternehmen und Behörden zu warten und zu pflegen. Für einen studierten Wissenschaftler ist der Umgang mit tatsächlichen Systemen aber oft auch mit einem gewissen Umdenken verbunden. Gerade in der Grundlagenforschung kann man sich darauf beschränken, die eigenen Modelle und Erkenntnisse immer weiter zu verfeinern. In der Praxis muss man aber irgendwann einen Schlussstrich ziehen und eine Entscheidung treffen, auch wenn man noch nicht alle Informationen verfügbar sind, die man gerne für die Entscheidung nutzen würde.

Nicht selten kommt es deswegen dazu, dass ein defektes System weiterbetrieben wird, anstatt es durch ein neues System zu ersetzen. Schließlich kennt man die Defekte des jetzigen Systems bereits und weiß, wie man mit ihnen umgehen kann. Ein neues System hingegen bringt mit hoher Wahrscheinlichkeit völlig neue, ungeahnte Defekte mit sich, die im Vornherein kaum abschätzen und quantifizieren kann.

Und auch diese Erkenntnis lässt sich von der IT auf alle Bereiche des menschlichen Handelns erweitern. Praktisches Handeln heißt immer Entscheiden im Angesicht unvollständiger Information. Kein Politiker kann die Folgen einer Gesetzesänderung komplett vorhersagen. Kein Chef kann sich sicher sein, dass er aus einer Gruppe von Bewerbern den besten Kandidaten auswählt. Und kein Passagier kann sich sicher sein, dass der Zug, in den er steigt, pünktlich sein Ziel erreicht.

Praktisches Handeln in diesem Sinne ist in der Bildung leider stark unterrepräsentiert. Zum Beispiel könnte der Geschichtsunterricht stärker darstellen, auf welcher Grundlage historische Akteure Entscheidungen getroffen haben, gerade wenn die Entscheidung im Angesicht der Faktenlage richtig war, sich aber aufgrund späterer Entwicklungen als fatal herausstellt. Wer versteht, dass gute Entscheidungen immer auf einer Momentaufnahme beruhen müssen, lernt auch, dass es keinen Sinn ergibt, Entscheidungen für falsch zu halten, nur weil es später zu Entwicklungen kommt, die der Entscheider nicht hätte vorhersehen können.

## Zusammenfassung

Diese drei Lektionen halten wir in der Bildung aktuell für fatal unterrepräsentiert: emergente Komplexität verstehen, aus neuen Informationen lernen können, und mit unvollständiger Information handeln können. Besonders deutlich wurde uns dies gerade in diesem Jahr, in dem die Coronavirus-Pandemie das öffentliche Leben bestimmt. Als prominente Gegenrede gegen die Handlungen der verschiedenen Regierungsebenen bildete sich die Bewegung der "Querdenker". Die Querdenker zeigen eindrucksvoll, welchen Schaden die Gesellschaft nehmen kann, wenn sie die obengenannten Lektionen nicht verinnerlicht.

Erstens kapitulieren Querdenker vor der emergenten Komplexität der globalisierten Welt und vermuten hinter jeder unangenehmen Entwicklung von langer Hand geplante Verschwörungen von mächtigen Geheimorganisationen.

Zweitens verharren Querdenker in ihren zu Beginn der Pandemie gefassten Meinungen und glauben teilweise immer noch, dass ein Virus mit über einer Million bestätigten Todesopfern gar nicht existiert.

Drittens kritisieren Querdenker die Regierung für Handlungen in der Frühphase der Pandemie, die sich in der Rückschau als zu strikt herausgestellt haben, ohne anzuerkennen, dass die heutigen Erkenntnisse damals noch nicht vorlagen.

Im Angesicht dessen halten wir es nicht für sinnvoll, weitere neue Sachkompetenzen im Lehrplan zu fordern, solange diese Sozialkompetenzen nicht hinreichend vermittelt werden. Das heißt nicht, dass wir im CCC selber diese Lektionen immer hundertprozentig befolgen. Schließlich sind wir auch nur Menschen und deswegen genauso mit den Limitationen des menschlichen Denkens konfrontiert. Aber wir sollten dafür sorgen, dass wir alle öfter lichte Momente haben und rechtzeitig bemerken, wenn wir gerade einen Holzweg beschreiten.
